==> halkyon-annotations-0.8.2.redhat-00001-sources.jar: io/dekorate/halkyon/config/ComponentConfigBuilder.java <==
package io.dekorate.halkyon.config;

import io.dekorate.deps.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ComponentConfigBuilder extends ComponentConfigFluentImpl<ComponentConfigBuilder> implements VisitableBuilder<ComponentConfig,ComponentConfigBuilder>{

    ComponentConfigFluent<?> fluent;
    Boolean validationEnabled;

    public ComponentConfigBuilder(){
            this(true);
    }
    public ComponentConfigBuilder(Boolean validationEnabled){
            this(new ComponentConfig(), validationEnabled);
    }
    public ComponentConfigBuilder(ComponentConfigFluent<?> fluent){
            this(fluent, true);
    }
    public ComponentConfigBuilder(ComponentConfigFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ComponentConfig(), validationEnabled);
    }
    public ComponentConfigBuilder(ComponentConfigFluent<?> fluent,ComponentConfig instance){
            this(fluent, instance, true);
    }
    public ComponentConfigBuilder(ComponentConfigFluent<?> fluent,ComponentConfig instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withProject(instance.getProject()); 
            fluent.withAttributes(instance.getAttributes()); 
            fluent.withName(instance.getName()); 
            fluent.withDeploymentMode(instance.getDeploymentMode()); 
            fluent.withExposeService(instance.isExposeService()); 
            fluent.withEnvs(instance.getEnvs()); 
            fluent.withBuildType(instance.getBuildType()); 
            fluent.withRemote(instance.getRemote()); 
            this.validationEnabled = validationEnabled; 
    }
    public ComponentConfigBuilder(ComponentConfig instance){
            this(instance,true);
    }
    public ComponentConfigBuilder(ComponentConfig instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withProject(instance.getProject()); 
            this.withAttributes(instance.getAttributes()); 
            this.withName(instance.getName()); 
            this.withDeploymentMode(instance.getDeploymentMode()); 
            this.withExposeService(instance.isExposeService()); 
            this.withEnvs(instance.getEnvs()); 
            this.withBuildType(instance.getBuildType()); 
            this.withRemote(instance.getRemote()); 
            this.validationEnabled = validationEnabled; 
    }

    public EditableComponentConfig build(){
            EditableComponentConfig buildable = new EditableComponentConfig(fluent.getProject(),fluent.getAttributes(),fluent.getName(),fluent.getDeploymentMode(),fluent.isExposeService(),fluent.getEnvs(),fluent.getBuildType(),fluent.getRemote());
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ComponentConfigBuilder that = (ComponentConfigBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> halkyon-annotations-0.10.10.redhat-00001-sources.jar: io/dekorate/halkyon/config/ComponentConfigBuilder.java <==
package io.dekorate.halkyon.config;

import io.dekorate.deps.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ComponentConfigBuilder extends ComponentConfigFluentImpl<ComponentConfigBuilder> implements VisitableBuilder<ComponentConfig,ComponentConfigBuilder>{

    ComponentConfigFluent<?> fluent;
    Boolean validationEnabled;

    public ComponentConfigBuilder(){
            this(true);
    }
    public ComponentConfigBuilder(Boolean validationEnabled){
            this(new ComponentConfig(), validationEnabled);
    }
    public ComponentConfigBuilder(ComponentConfigFluent<?> fluent){
            this(fluent, true);
    }
    public ComponentConfigBuilder(ComponentConfigFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ComponentConfig(), validationEnabled);
    }
    public ComponentConfigBuilder(ComponentConfigFluent<?> fluent,ComponentConfig instance){
            this(fluent, instance, true);
    }
    public ComponentConfigBuilder(ComponentConfigFluent<?> fluent,ComponentConfig instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withProject(instance.getProject()); 
            fluent.withAttributes(instance.getAttributes()); 
            fluent.withGroup(instance.getGroup()); 
            fluent.withName(instance.getName()); 
            fluent.withVersion(instance.getVersion()); 
            fluent.withDeploymentMode(instance.getDeploymentMode()); 
            fluent.withExposeService(instance.isExposeService()); 
            fluent.withEnvs(instance.getEnvs()); 
            fluent.withLabels(instance.getLabels()); 
            fluent.withBuildType(instance.getBuildType()); 
            fluent.withRemote(instance.getRemote()); 
            this.validationEnabled = validationEnabled; 
    }
    public ComponentConfigBuilder(ComponentConfig instance){
            this(instance,true);
    }
    public ComponentConfigBuilder(ComponentConfig instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withProject(instance.getProject()); 
            this.withAttributes(instance.getAttributes()); 
            this.withGroup(instance.getGroup()); 
            this.withName(instance.getName()); 
            this.withVersion(instance.getVersion()); 
            this.withDeploymentMode(instance.getDeploymentMode()); 
            this.withExposeService(instance.isExposeService()); 
            this.withEnvs(instance.getEnvs()); 
            this.withLabels(instance.getLabels()); 
            this.withBuildType(instance.getBuildType()); 
            this.withRemote(instance.getRemote()); 
            this.validationEnabled = validationEnabled; 
    }

    public EditableComponentConfig build(){
            EditableComponentConfig buildable = new EditableComponentConfig(fluent.getProject(),fluent.getAttributes(),fluent.getGroup(),fluent.getName(),fluent.getVersion(),fluent.getDeploymentMode(),fluent.isExposeService(),fluent.getEnvs(),fluent.getLabels(),fluent.getBuildType(),fluent.getRemote());
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ComponentConfigBuilder that = (ComponentConfigBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
